==> haskell-generic-random-1.5.0.1-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-EC4xBQi0xoEAUqb0lx2kMC
key:                  generic-random-1.5.0.1-EC4xBQi0xoEAUqb0lx2kMC
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  181270d7ff71566af06cf32e0b7aada8
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-random
hs-libraries:         HSgeneric-random-1.5.0.1-EC4xBQi0xoEAUqb0lx2kMC
depends:
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-random-1.5.0.1-165-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-random
version:              1.5.0.1
visibility:           public
id:                   generic-random-1.5.0.1-HPAuF8BTEWR9O7Z2oAVl6K
key:                  generic-random-1.5.0.1-HPAuF8BTEWR9O7Z2oAVl6K
license:              MIT
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
stability:            Stable
homepage:             http://github.com/lysxia/generic-random
synopsis:             Generic random generators for QuickCheck
description:
    Derive instances of @Arbitrary@ for QuickCheck,
    with various options to customize implementations.

    For more information

    - See the README

    - "Generic.Random.Tutorial"

    - http://blog.poisson.chat/posts/2018-01-05-generic-random-tour.html

category:             Generics, Testing
abi:                  8b3b763153d928aecc89eaf9e79ebbea
exposed:              True
exposed-modules:
    Generic.Random Generic.Random.DerivingVia
    Generic.Random.Internal.BaseCase Generic.Random.Internal.Generic
    Generic.Random.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-random-1.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-random
hs-libraries:         HSgeneric-random-1.5.0.1-HPAuF8BTEWR9O7Z2oAVl6K
depends:
    QuickCheck-2.15.0.1-9BbRJGxXLRp2lnC2CpyIBM base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-generic-random/html/generic-random.haddock

haddock-html:         /usr/share/doc/haskell-generic-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
